@@ -4,7 +4,7 @@ Email: erik.rydow@eng.ox.ac.uk
 '''
 
 from .gaussian_process_emulator import split_training_test_set, train_GP_emulator, predict_GP_emulator, \
-    evaluate_GP_emulator, train_and_predict, form_training_set, form_test_set
+    evaluate_GP_emulator, train_and_predict, form_training_set, form_test_set, get_scalar_features
 
 from . import sensitivity_analysis
 from . import uncertainty_quantification
@@ -17,6 +17,7 @@ __all__ = ["split_training_test_set",
            "train_and_predict",
            "form_training_set",
            "form_test_set",
+           "get_scalar_features",
            "sensitivity_analysis",
            "uncertainty_quantification",
            "data_types"
